@@ -9,4 +9,6 @@
 # Update this function call
 utils::globalVariables(c("category","%>%","arrange","mutate","desc","aes","xlab","geom_bar","ggplot","theme_minimal","product_mix","ldply",
                          "ggplotly","Product_name","Measure","Value","revenue","profit","predicted_linear","predicted_logit",
-                         "revenue_linear","revenue_logit","lm_p","logit_p"))
+                         "revenue_linear","revenue_logit","lm_p","logit_p","dplyr::filter","dplyr::lag"))
+
+
